$fn = 96;

	module arm(){
		cube([16,16,6], center=true);
		hull(){
			cube([1,12,6], center=true);
			translate([21,0,0]) cylinder(h=6, d=3, center=true);
		}
		translate([15,5,0]) cube([4,2,50], center=true);
		translate([15,-5,0]) cube([4,2,50], center=true);
	}
difference(){
	union(){
		herringbone_gear(2, 24, 15/2, 0, engagement_angle = 20, angle_of_inclination = 30);
		translate([0,0,15/2]) herringbone_gear(2, 24, 15/2, 0, engagement_angle = 20, angle_of_inclination = 30);
	}
	cylinder(h=18, d=3.5);
	cylinder(h=5, d=8);

	arm();
	rotate([0,0,90]) arm();
	rotate([0,0,180]) arm();
	rotate([0,0,-90]) arm();
}

/*Library for involute gears

Contains the modules
1. spur_gear (scale_of, number of teeth, height, bore, engagement_angle = 20, angleof_inclination = 0)
1. herringbone_gear (scale_of, number of teeth, height, bore, angle of engagement = 20, angle of inclination = 0)
3. hollow_gear (scale_of, number of teeth, height, edge width, engagement angle = 20, angle of inclination = 0
4. arrowhead (modulus, number of teeth, height, edge width, angle of engagement = 20, angle of inclination = 0)
5. planetary_gear_units (scale_of, tooth number, tooth number_planet, height, edge width, bore, engagement angle = 20, angle of inclination = 0)
6. bevel_gear (scale_of, tooth number, partial cone angle, tooth width, bore, engagement angle = 20)
7. Pipe_bevel_gear (scale_of, tooth number, partial cone angle, tooth width, bore, engagement angle = 20, angle of inclination = 10)
8. bevel_gear_pair (scale_of, tooth number_wheel, tooth number_curve, tooth width, bore, engagement angle = 20, bevel angle = 0)
Beigamee für jedes Modul befinden sich auskommentiert am Ende dieser Datei

Examples for each module are found at the end of this file

Author: Dr Jörg Janssen
Stand: June 20, 2016
Version: 1.3
License: Creative Commons - Attribution, Non Commercial, Share Alike

Permitted modules according to DIN 780:
0.05 0.06 0.08 0.10 0.12 0.16
0.20 0.25 0.3 0.4 0.5 0.6
0.7 0.8 0.9 1 1.25 1.5
2 2.5 3 4 5 6
8 10 12 16 20 25
32 40 50 60

*/


// General variables
pi = 3.14159;
rad = 57.29578;
game = 0.05;	// Play between teeth

/* Convert Radian to degrees */
function grad(engagement_angle) =  engagement_angle*rad;

/* Converts degrees to radians */
function radian(engagement_angle) = engagement_angle/rad;

/* Convert 2D polar coordinates to Cartesian
    Format: radius, phi; Phi = angle to x-axis on xy-plane */
function pol_zu_kart(polvect) = [
	polvect[0]*cos(polvect[1]),  
	polvect[0]*sin(polvect[1])
];

/* Circular flow function:
    Outputs the polar coordinates of a circular arc
    R = radius of the base circle
    Rho = rolling angle in degrees */
function ev(r,rho) = [
	r/cos(rho),
	grad(tan(rho)-radian(rho))
];

/*  Kugelevolventen-Funktion
    Gibt den Azimutwinkel einer Kugelevolvente aus
    theta0 = Polarwinkel des Kegels, an dessen Schnittkante zum Großkugel die Evolvente abrollt
    theta = Polarwinkel, für den der Azimutwinkel der Evolvente berechnet werden soll */
function kugelev(theta0,theta) = 1/sin(theta0)*acos(cos(theta)/cos(theta0))-acos(tan(theta0)/tan(theta));

/* Headlamp function
    Returns the azimuth angle of a spherical lens
    Theta0 = Polar angle of the cone, at the cutting edge of which the roller is rolled
    Theta = polar angle for which the azimuth angle of the involute is to be calculated */
function kugel_zu_kart(vect) = [
	vect[0]*sin(vect[1])*cos(vect[2]),  
	vect[0]*sin(vect[1])*sin(vect[2]),
	vect[0]*cos(vect[1])
];

/*	prüft, ob eine Zahl gerade ist
	= 1, wenn ja
	= 0, wenn die Zahl nicht gerade ist */
function istgerade(zahl) =
	(zahl == floor(zahl/2)*2) ? 1 : 0;

/*	größter gemeinsamer Teiler
	nach Euklidischem Algorithmus.
	Sortierung: a muss größer als b sein */
function ggt(a,b) = 
	a%b == 0 ? b : ggt(b,a%b);

/*  spur_gear
    scale_of = Höhe des Zahnkopfes über dem Teilkreis
    number_of_teeth = Anzahl der Radzähne
    hoehe = Höhe des Zahnrads
    bohrung = Durchmesser der Mittelbohrung
    engagement_angle = engagement_angle, Standardwert = 20° gemäß DIN 867
    angle_of_inclination = Schrägungswinkel zur Rotationsachse; 0° = Geradverzahnung */
module spur_gear(scale_of, number_of_teeth, hoehe, bohrung, engagement_angle = 20, angle_of_inclination = 0) {

	// Dimensions-Berechnungen	
	d = scale_of * number_of_teeth;								// Teilkreisdurchmesser
	r = d / 2;											// Teilkreisradius
	alpha_stirn = atan(tan(engagement_angle)/cos(angle_of_inclination));	// Schrägungswinkel im Stirnschnitt
	db = d * cos(alpha_stirn);							// Grundkreisdurchmesser
	rb = db / 2;										// Grundkreisradius
	da = (scale_of <1)? d + scale_of * 2.2 : d + scale_of * 2;	// Kopfkreisdurchmesser nach DIN 58400 bzw. DIN 867
	ra = da / 2;										// Kopfkreisradius
	c = scale_of / 6;										// Kopfgame
	df = d - 2 * (scale_of + c);							// Fußkreisdurchmesser
	rf = df / 2;										// Fußkreisradius
	rho_ra = acos(rb/ra);								// maximaler Abrollwinkel;
														// Evolvente beginnt auf Grundkreis und endet an Kopfkreis
	rho_r = acos(rb/r);									// Abrollwinkel am Teilkreis;
														// Evolvente beginnt auf Grundkreis und endet an Kopfkreis
	phi_r = grad(tan(rho_r)-radian(rho_r));				// Winkel zum Punkt der Evolvente auf Teilkreis
	gamma = rad*hoehe/(r*tan(90-angle_of_inclination));	// Torsionswinkel für Extrusion
	schritt = rho_ra/16;								// Evolvente wird in 16 Stücke geteilt
	tau = 360/number_of_teeth;									// Teilungswinkel

	// Zeichnung
	rotate([0,0,-phi_r-90*(1-game)/number_of_teeth]){				// Zahn auf x-Achse zentrieren;
															// macht Ausrichtung mit anderen Rädern einfacher

		linear_extrude(height = hoehe, twist = gamma){
			difference(){
				union(){
					zahnbreite = (180*(1-game))/number_of_teeth+2*phi_r;
					circle(rf);										// Fußkreis	
					for (rot = [0:tau:360]){
						rotate (rot){								// "number_of_teeth-mal" kopieren und drehen
							polygon(concat(							// Zahn
								[[0,0]],							// Zahnsegment beginnt und endet im Ursprung
								[for (rho = [0:schritt:rho_ra])		// von null Grad (Grundkreis)
																	// bis maximalen Evolventenwinkel (Kopfkreis)
									pol_zu_kart(ev(rb,rho))],		// Erste Evolventen-Flanke

								[pol_zu_kart(ev(rb,rho_ra))],		// Punkt der Evolvente auf Kopfkreis

								[for (rho = [rho_ra:-schritt:0])	// von maximalen Evolventenwinkel (Kopfkreis)
																	// bis null Grad (Grundkreis)
									pol_zu_kart([ev(rb,rho)[0], zahnbreite-ev(rb,rho)[1]])]
																	// Zweite Evolventen-Flanke
																	// (180*(1-game)) statt 180 Grad,
																	// um game an den Flanken zu erlauben
								)
							);
						}
					}
				}
				circle(r = bohrung/2);								// Bohrung
			}
		}
	}
}


/*  herringbone_gear; verwendet das Modul "spur_gear"
    scale_of = Höhe des Zahnkopfes über dem Teilkreis
    number_of_teeth = Anzahl der Radzähne
    hoehe = Höhe des Zahnrads
    bohrung = Durchmesser der Mittelbohrung
    engagement_angle = engagement_angle, Standardwert = 20° gemäß DIN 867
    angle_of_inclination = Schrägungswinkel zur Rotationsachse, Standardwert = 0° (Geradverzahnung) */
module herringbone_gear(scale_of, number_of_teeth, hoehe, bohrung, engagement_angle = 20, angle_of_inclination = 0){

	hoehe = hoehe/2;

	translate([0,0,hoehe]){
		union(){
			spur_gear(scale_of, number_of_teeth, hoehe, bohrung, engagement_angle, angle_of_inclination);		// untere Hälfte
			mirror([0,0,1]){
				spur_gear(scale_of, number_of_teeth, hoehe, bohrung, engagement_angle, angle_of_inclination);	// obere Hälfte
			}
		}
	}
}


/*
    scale_of = Höhe des Zahnkopfes über dem Teilkreis
    number_of_teeth = Anzahl der Radzähne
    hoehe = Höhe des Zahnrads
	randbreite = Breite des Randes ab Fußkreis
    bohrung = Durchmesser der Mittelbohrung
    engagement_angle = engagement_angle, Standardwert = 20° gemäß DIN 867
    angle_of_inclination = Schrägungswinkel zur Rotationsachse, Standardwert = 0° (Geradverzahnung) */
module hollow_gear(scale_of, number_of_teeth, hoehe, randbreite, engagement_angle = 20, angle_of_inclination = 0) {

	// Dimensions-Berechnungen	
	ha = (number_of_teeth >= 20) ? 0.02 * atan((number_of_teeth/15)/pi) : 0.6;	// Verkürzungsfaktor Zahnkopfhöhe
	d = scale_of * number_of_teeth;											// Teilkreisdurchmesser
	r = d / 2;														// Teilkreisradius
	alpha_stirn = atan(tan(engagement_angle)/cos(angle_of_inclination));// Schrägungswinkel im Stirnschnitt
	db = d * cos(alpha_stirn);										// Grundkreisdurchmesser
	rb = db / 2;													// Grundkreisradius
	c = scale_of / 6;													// Kopfgame
	da = (scale_of <1)? d + (scale_of+c) * 2.2 : d + (scale_of+c) * 2;		// Kopfkreisdurchmesser
	ra = da / 2;													// Kopfkreisradius
	df = d - 2 * scale_of * ha;										// Fußkreisdurchmesser
	rf = df / 2;													// Fußkreisradius
	rho_ra = acos(rb/ra);											// maximaler Evolventenwinkel;
																	// Evolvente beginnt auf Grundkreis und endet an Kopfkreis
	rho_r = acos(rb/r);												// Evolventenwinkel am Teilkreis;
																	// Evolvente beginnt auf Grundkreis und endet an Kopfkreis
	phi_r = grad(tan(rho_r)-radian(rho_r));							// Winkel zum Punkt der Evolvente auf Teilkreis
	gamma = rad*hoehe/(r*tan(90-angle_of_inclination));				// Torsionswinkel für Extrusion
	schritt = rho_ra/16;											// Evolvente wird in 16 Stücke geteilt
	tau = 360/number_of_teeth;												// Teilungswinkel

	// Zeichnung
	rotate([0,0,-phi_r-90*(1+game)/number_of_teeth])						// Zahn auf x-Achse zentrieren;
																	// macht Ausrichtung mit anderen Rädern einfacher
	linear_extrude(height = hoehe, twist = gamma){
		difference(){
			circle(r = ra + randbreite);							// Außenkreis
			union(){
				zahnbreite = (180*(1+game))/number_of_teeth+2*phi_r;
				circle(rf);											// Fußkreis	
				for (rot = [0:tau:360]){
					rotate (rot) {									// "number_of_teeth-mal" kopieren und drehen
						polygon( concat(
							[[0,0]],
							[for (rho = [0:schritt:rho_ra])			// von null Grad (Grundkreis)
																	// bis maximaler Evolventenwinkel (Kopfkreis)
								pol_zu_kart(ev(rb,rho))],
							[pol_zu_kart(ev(rb,rho_ra))],
							[for (rho = [rho_ra:-schritt:0])		// von maximaler Evolventenwinkel (Kopfkreis)
																	// bis null Grad (Grundkreis)
								pol_zu_kart([ev(rb,rho)[0], zahnbreite-ev(rb,rho)[1]])]
																	// (180*(1+game)) statt 180,
																	// um game an den Flanken zu erlauben
							)
						);
					}
				}
			}
		}
	}

	echo("Außendurchmesser hollow_gear = ", 2*(ra + randbreite));
	
}

/*  Pfeil-hollow_gear; verwendet das Modul "hollow_gear"
    scale_of = Höhe des Zahnkopfes über dem Teilkegel
    number_of_teeth = Anzahl der Radzähne
    hoehe = Höhe des Zahnrads
    bohrung = Durchmesser der Mittelbohrung
    engagement_angle = engagement_angle, Standardwert = 20° gemäß DIN 867
    angle_of_inclination = Schrägungswinkel zur Rotationsachse, Standardwert = 0° (Geradverzahnung) */
module pfeilhollow_gear(scale_of, number_of_teeth, hoehe, randbreite, engagement_angle = 20, angle_of_inclination = 0) {

	hoehe = hoehe / 2;
	translate([0,0,hoehe])
		union(){
		hollow_gear(scale_of, number_of_teeth, hoehe, randbreite, engagement_angle, angle_of_inclination);		// untere Hälfte
		mirror([0,0,1])
			hollow_gear(scale_of, number_of_teeth, hoehe, randbreite, engagement_angle, angle_of_inclination);	// obere Hälfte
	}
}

/*	planetary_gear_units; verwendet die Module "herringbone_gear" und "pfeilhollow_gear"
    scale_of = Höhe des Zahnkopfes über dem Teilkegel
    number_of_teeth_sonne = Anzahl der Zähne des Sonnenrads
    number_of_teeth_planet = Anzahl der Zähne eines Planetenrads
    hoehe = Höhe des Zahnrads
	randbreite = Breite des Randes ab Fußkreis
    bohrung = Durchmesser der Mittelbohrung
    engagement_angle = engagement_angle, Standardwert = 20° gemäß DIN 867
    angle_of_inclination = Schrägungswinkel zur Rotationsachse, Standardwert = 0° (Geradverzahnung) */
module planetary_gear_units(scale_of, number_of_teeth_sonne, number_of_teeth_planet, hoehe, randbreite, bohrung, engagement_angle=20, angle_of_inclination=0){

	// Dimensions-Berechnungen
	d_sonne = scale_of*number_of_teeth_sonne;										// Teilkreisdurchmesser Sonne
	d_planet = scale_of*number_of_teeth_planet;									// Teilkreisdurchmesser Planeten
	achsabstand = (scale_of*number_of_teeth_sonne +  scale_of*number_of_teeth_planet) / 2;	// Abstand von Sonnenrad-/hollow_gearachse und Planetenachse
	number_of_teeth_hollow_gear = number_of_teeth_sonne + 2*number_of_teeth_planet;				// Anzahl der Zähne des hollow_geares

	drehen = istgerade(number_of_teeth_planet);								// Muss das Sonnenrad gedreht werden?
		
	n_planeten = (number_of_teeth_planet>number_of_teeth_sonne) ? ggt(number_of_teeth_planet,number_of_teeth_sonne) : ggt(number_of_teeth_sonne,number_of_teeth_planet);
																		// Anzahl Planetenräder = größter gemeinsamer
																		// Teiler von Anzahl der Zähne des Sonnen- und
																		// Planetenrads
	
	// Zeichnung
	rotate([0,0,180/number_of_teeth_sonne*drehen]){
		herringbone_gear (scale_of, number_of_teeth_sonne, hoehe, bohrung, engagement_angle, -angle_of_inclination);		// Sonnenrad
	}

	for(rot=[0:360/n_planeten:360/n_planeten*(n_planeten-1)]){
		translate(kugel_zu_kart([achsabstand,90,rot]))
			herringbone_gear (scale_of, number_of_teeth_planet, hoehe, bohrung, engagement_angle, angle_of_inclination);	// Planetenräder
		}
	
	pfeilhollow_gear (scale_of, number_of_teeth_hollow_gear, hoehe, randbreite, engagement_angle, angle_of_inclination);	// hollow_gear
}

/*  bevel_gear
    scale_of = Höhe des Zahnkopfes über dem Teilkegel; Angabe für die Aussenseite des Kegels
    number_of_teeth = Anzahl der Radzähne
    teilkegelwinkel = (Halb)winkel des Kegels, auf dem das jeweils andere hollow_gear abrollt
    zahnbreite = Breite der Zähne von der Außenseite in Richtung Kegelspitze
    bohrung = Durchmesser der Mittelbohrung
    engagement_angle = engagement_angle, Standardwert = 20° gemäß DIN 867
	angle_of_inclination = Schrägungswinkel, Standardwert = 0° */
module bevel_gear(scale_of, number_of_teeth, teilkegelwinkel, zahnbreite, bohrung, engagement_angle = 20, angle_of_inclination=0) {

	// Dimensions-Berechnungen
	d_aussen = scale_of * number_of_teeth;									// Teilkegeldurchmesser auf der Kegelgrundfläche,
																	// entspricht der Sehne im Kugelschnitt
	r_aussen = d_aussen / 2;										// Teilbevel_gearius auf der Kegelgrundfläche 
	rg_aussen = r_aussen/sin(teilkegelwinkel);						// Großbevel_gearius für Zahn-Außenseite, entspricht der Länge der Kegelflanke;
	rg_innen = rg_aussen - zahnbreite;								// Großbevel_gearius für Zahn-Innenseite	
	r_innen = r_aussen*rg_innen/rg_aussen;
	alpha_stirn = atan(tan(engagement_angle)/cos(angle_of_inclination));// Schrägungswinkel im Stirnschnitt
	delta_b = asin(cos(alpha_stirn)*sin(teilkegelwinkel));			// Grundkegelwinkel		
	da_aussen = (scale_of <1)? d_aussen + (scale_of * 2.2) * cos(teilkegelwinkel): d_aussen + scale_of * 2 * cos(teilkegelwinkel);
	ra_aussen = da_aussen / 2;
	delta_a = asin(ra_aussen/rg_aussen);
	c = scale_of / 6;													// Kopfgame
	df_aussen = d_aussen - (scale_of +c) * 2 * cos(teilkegelwinkel);
	rf_aussen = df_aussen / 2;
	delta_f = asin(rf_aussen/rg_aussen);
	rkf = rg_aussen*sin(delta_f);									// Radius des Kegelfußes
	hoehe_f = rg_aussen*cos(delta_f);								// Höhe des Kegels vom Fußkegel
	
	echo("Teilkegeldurchmesser auf der Kegelgrundfläche = ", d_aussen);
	
	// Größen für Komplementär-Kegelstumpf
	hoehe_k = (rg_aussen-zahnbreite)/cos(teilkegelwinkel);			// Höhe des Komplementärkegels für richtige Zahnlänge
	rk = (rg_aussen-zahnbreite)/sin(teilkegelwinkel);				// Fußradius des Komplementärkegels
	rfk = rk*hoehe_k*tan(delta_f)/(rk+hoehe_k*tan(delta_f));		// Kopfradius des Zylinders für 
																	// Komplementär-Kegelstumpf
	hoehe_fk = rk*hoehe_k/(hoehe_k*tan(delta_f)+rk);				// Hoehe des Komplementär-Kegelstumpfs

	echo("Höhe bevel_gear = ", hoehe_f-hoehe_fk);
	
	phi_r = kugelev(delta_b, teilkegelwinkel);						// Winkel zum Punkt der Evolvente auf Teilkegel
		
	// Torsionswinkel gamma aus Schrägungswinkel
	gamma_g = 2*atan(zahnbreite*tan(angle_of_inclination)/(2*rg_aussen-zahnbreite));
	gamma = 2*asin(rg_aussen/r_aussen*sin(gamma_g/2));
	
	schritt = (delta_a - delta_b)/16;
	tau = 360/number_of_teeth;												// Teilungswinkel
	start = (delta_b > delta_f) ? delta_b : delta_f;
	spiegelpunkt = (180*(1-game))/number_of_teeth+2*phi_r;

	// Zeichnung
	rotate([0,0,phi_r+90*(1-game)/number_of_teeth]){						// Zahn auf x-Achse zentrieren;
																	// macht Ausrichtung mit anderen Rädern einfacher
		translate([0,0,hoehe_f]) rotate(a=[0,180,0]){
			union(){
				translate([0,0,hoehe_f]) rotate(a=[0,180,0]){								// Kegelstumpf							
					difference(){
						linear_extrude(height=hoehe_f-hoehe_fk, scale=rfk/rkf) circle(rkf);
						translate([0,0,-1]){
							cylinder(h = hoehe_f-hoehe_fk+2, r = bohrung/2);				// Bohrung
						}
					}	
				}
				for (rot = [0:tau:360]){
					rotate (rot) {															// "number_of_teeth-mal" kopieren und drehen
						union(){
							if (delta_b > delta_f){
								// Zahnfuß
								flankenpunkt_unten = 1*spiegelpunkt;
								flankenpunkt_oben = kugelev(delta_f, start);
								polyhedron(
									points = [
										kugel_zu_kart([rg_aussen, start*1.001, flankenpunkt_unten]),	// 1 promille Überlappung mit Zahn
										kugel_zu_kart([rg_innen, start*1.001, flankenpunkt_unten+gamma]),
										kugel_zu_kart([rg_innen, start*1.001, spiegelpunkt-flankenpunkt_unten+gamma]),
										kugel_zu_kart([rg_aussen, start*1.001, spiegelpunkt-flankenpunkt_unten]),								
										kugel_zu_kart([rg_aussen, delta_f, flankenpunkt_unten]),
										kugel_zu_kart([rg_innen, delta_f, flankenpunkt_unten+gamma]),
										kugel_zu_kart([rg_innen, delta_f, spiegelpunkt-flankenpunkt_unten+gamma]),
										kugel_zu_kart([rg_aussen, delta_f, spiegelpunkt-flankenpunkt_unten])								
									],
									faces = [[0,1,2],[0,2,3],[0,4,1],[1,4,5],[1,5,2],[2,5,6],[2,6,3],[3,6,7],[0,3,7],[0,7,4],[4,6,5],[4,7,6]],
									convexity =1
								);
							}
							// Zahn
							for (delta = [start:schritt:delta_a-schritt]){
								flankenpunkt_unten = kugelev(delta_b, delta);
								flankenpunkt_oben = kugelev(delta_b, delta+schritt);
								polyhedron(
									points = [
										kugel_zu_kart([rg_aussen, delta, flankenpunkt_unten]),
										kugel_zu_kart([rg_innen, delta, flankenpunkt_unten+gamma]),
										kugel_zu_kart([rg_innen, delta, spiegelpunkt-flankenpunkt_unten+gamma]),
										kugel_zu_kart([rg_aussen, delta, spiegelpunkt-flankenpunkt_unten]),								
										kugel_zu_kart([rg_aussen, delta+schritt, flankenpunkt_oben]),
										kugel_zu_kart([rg_innen, delta+schritt, flankenpunkt_oben+gamma]),
										kugel_zu_kart([rg_innen, delta+schritt, spiegelpunkt-flankenpunkt_oben+gamma]),
										kugel_zu_kart([rg_aussen, delta+schritt, spiegelpunkt-flankenpunkt_oben])									
									],
									faces = [[0,1,2],[0,2,3],[0,4,1],[1,4,5],[1,5,2],[2,5,6],[2,6,3],[3,6,7],[0,3,7],[0,7,4],[4,6,5],[4,7,6]],
									convexity =1
								);
							}
						}
					}
				}	
			}
		}
	}
}

/*  Pfeil-bevel_gear; verwendet das Modul "bevel_gear"
    scale_of = Höhe des Zahnkopfes über dem Teilkreis
    number_of_teeth = Anzahl der Radzähne
    hoehe = Höhe des Zahnrads
    bohrung = Durchmesser der Mittelbohrung
    engagement_angle = engagement_angle, Standardwert = 20° gemäß DIN 867
    angle_of_inclination = Schrägungswinkel, Standardwert = 0° */
module pfeilbevel_gear(scale_of, number_of_teeth, teilkegelwinkel, zahnbreite, bohrung, engagement_angle = 20, angle_of_inclination=0){

	// Dimensions-Berechnungen
	
	zahnbreite = zahnbreite / 2;
	
	d_aussen = scale_of * number_of_teeth;								// Teilkegeldurchmesser auf der Kegelgrundfläche,
																// entspricht der Sehne im Kugelschnitt
	r_aussen = d_aussen / 2;									// Teilbevel_gearius auf der Kegelgrundfläche 
	rg_aussen = r_aussen/sin(teilkegelwinkel);					// Großbevel_gearius, entspricht der Länge der Kegelflanke;
	c = scale_of / 6;												// Kopfgame
	df_aussen = d_aussen - (scale_of +c) * 2 * cos(teilkegelwinkel);
	rf_aussen = df_aussen / 2;
	delta_f = asin(rf_aussen/rg_aussen);
	hoehe_f = rg_aussen*cos(delta_f);							// Höhe des Kegels vom Fußkegel

	// Torsionswinkel gamma aus Schrägungswinkel
	gamma_g = 2*atan(zahnbreite*tan(angle_of_inclination)/(2*rg_aussen-zahnbreite));
	gamma = 2*asin(rg_aussen/r_aussen*sin(gamma_g/2));
	
	echo("Teilkegeldurchmesser auf der Kegelgrundfläche = ", d_aussen);
	
	// Größen für Komplementär-Kegelstumpf
	hoehe_k = (rg_aussen-zahnbreite)/cos(teilkegelwinkel);		// Höhe des Komplementärkegels für richtige Zahnlänge
	rk = (rg_aussen-zahnbreite)/sin(teilkegelwinkel);			// Fußradius des Komplementärkegels
	rfk = rk*hoehe_k*tan(delta_f)/(rk+hoehe_k*tan(delta_f));	// Kopfradius des Zylinders für 
																// Komplementär-Kegelstumpf
	hoehe_fk = rk*hoehe_k/(hoehe_k*tan(delta_f)+rk);			// Hoehe des Komplementär-Kegelstumpfs
	
	scale_of_innen = scale_of-zahnbreite/rg_aussen;

		union(){
		bevel_gear(scale_of, number_of_teeth, teilkegelwinkel, zahnbreite, bohrung, engagement_angle, angle_of_inclination);		// untere Hälfte
		translate([0,0,hoehe_f-hoehe_fk])
			rotate(a=-gamma,v=[0,0,1])
				bevel_gear(scale_of_innen, number_of_teeth, teilkegelwinkel, zahnbreite, bohrung, engagement_angle, -angle_of_inclination);	// obere Hälfte
	}
}

/*	bevel_gearpaar mit beliebigem Achsenwinkel; verwendet das Modul "bevel_gear"
    scale_of = Höhe des Zahnkopfes über dem Teilkegel; Angabe für die Aussenseite des Kegels
    number_of_teeth_rad = Anzahl der Radzähne am Rad
    number_of_teeth_ritzel = Anzahl der Radzähne am Ritzel
	achsenwinkel = Winkel zwischen den Achsen von Rad und Ritzel
    zahnbreite = Breite der Zähne von der Außenseite in Richtung Kegelspitze
    bohrung_rad = Durchmesser der Mittelbohrung des Rads
    bohrung_ritzel = Durchmesser der Mittelbohrungen des Ritzels
    engagement_angle = engagement_angle, Standardwert = 20° gemäß DIN 867
	angle_of_inclination = Schrägungswinkel, Standardwert = 0° */
module bevel_gearpaar(scale_of, number_of_teeth_rad, number_of_teeth_ritzel, achsenwinkel=90, zahnbreite, bohrung_rad, bohrung_ritzel, engagement_angle=20, angle_of_inclination=0, zusammen_gebaut=1){
 
	// Dimensions-Berechnungen
	r_rad = scale_of*number_of_teeth_rad/2;							// Teilbevel_gearius des Rads
	delta_rad = atan(sin(achsenwinkel)/(number_of_teeth_ritzel/number_of_teeth_rad+cos(achsenwinkel)));	// Kegelwinkel des Rads
	delta_ritzel = atan(sin(achsenwinkel)/(number_of_teeth_rad/number_of_teeth_ritzel+cos(achsenwinkel)));// Kegelwingel des Ritzels
	rg = r_rad/sin(delta_rad);								// Radius der Großkugel
	c = scale_of / 6;											// Kopfgame
	df_ritzel = 4*pi*rg*delta_ritzel/360 - 2 * (scale_of + c);	// Fußkegeldurchmesser auf der Großkugel 
	rf_ritzel = df_ritzel / 2;								// Fußbevel_gearius auf der Großkugel
	delta_f_ritzel = rf_ritzel/(2*pi*rg) * 360;				// Kopfkegelwinkel
	rkf_ritzel = rg*sin(delta_f_ritzel);					// Radius des Kegelfußes
	hoehe_f_ritzel = rg*cos(delta_f_ritzel);				// Höhe des Kegels vom Fußkegel
	
	echo("Kegelwinkel Rad = ", delta_rad);
	echo("Kegelwinkel Ritzel = ", delta_ritzel);
 
	df_rad = 4*pi*rg*delta_rad/360 - 2 * (scale_of + c);		// Fußkegeldurchmesser auf der Großkugel 
	rf_rad = df_rad / 2;									// Fußbevel_gearius auf der Großkugel
	delta_f_rad = rf_rad/(2*pi*rg) * 360;					// Kopfkegelwinkel
	rkf_rad = rg*sin(delta_f_rad);							// Radius des Kegelfußes
	hoehe_f_rad = rg*cos(delta_f_rad);						// Höhe des Kegels vom Fußkegel

	echo("Höhe Rad = ", hoehe_f_rad);
	echo("Höhe Ritzel = ", hoehe_f_ritzel);
	
	drehen = istgerade(number_of_teeth_ritzel);
	
	// Zeichnung
	// Rad
	rotate([0,0,180*(1-game)/number_of_teeth_rad*drehen])
		bevel_gear(scale_of, number_of_teeth_rad, delta_rad, zahnbreite, bohrung_rad, engagement_angle, angle_of_inclination);
	
	// Ritzel
	if (zusammen_gebaut == 1)
		translate([-hoehe_f_ritzel*cos(90-achsenwinkel),0,hoehe_f_rad-hoehe_f_ritzel*sin(90-achsenwinkel)])
			rotate([0,achsenwinkel,0])
				bevel_gear(scale_of, number_of_teeth_ritzel, delta_ritzel, zahnbreite, bohrung_ritzel, engagement_angle, -angle_of_inclination);
	else
		translate([rkf_ritzel*2+scale_of+rkf_rad,0,0])
			bevel_gear(scale_of, number_of_teeth_ritzel, delta_ritzel, zahnbreite, bohrung_ritzel, engagement_angle, -angle_of_inclination);
 }

/*	Pfeil-bevel_gearpaar mit beliebigem Achsenwinkel; verwendet das Modul "pfeilbevel_gear"
    scale_of = Höhe des Zahnkopfes über dem Teilkegel; Angabe für die Aussenseite des Kegels
    number_of_teeth_rad = Anzahl der Radzähne am Rad
    number_of_teeth_ritzel = Anzahl der Radzähne am Ritzel
	achsenwinkel = Winkel zwischen den Achsen von Rad und Ritzel
    zahnbreite = Breite der Zähne von der Außenseite in Richtung Kegelspitze
    bohrung_rad = Durchmesser der Mittelbohrung des Rads
    bohrung_ritzel = Durchmesser der Mittelbohrungen des Ritzels
    engagement_angle = engagement_angle, Standardwert = 20° gemäß DIN 867
    angle_of_inclination = Schrägungswinkel, Standardwert = 0° */
module pfeilbevel_gearpaar(scale_of, number_of_teeth_rad, number_of_teeth_ritzel, achsenwinkel=90, zahnbreite, bohrung_rad, bohrung_ritzel, engagement_angle = 20, angle_of_inclination=10, zusammen_gebaut=1){
 
	r_rad = scale_of*number_of_teeth_rad/2;							// Teilbevel_gearius des Rads
	delta_rad = atan(sin(achsenwinkel)/(number_of_teeth_ritzel/number_of_teeth_rad+cos(achsenwinkel)));	// Kegelwinkel des Rads
	delta_ritzel = atan(sin(achsenwinkel)/(number_of_teeth_rad/number_of_teeth_ritzel+cos(achsenwinkel)));// Kegelwingel des Ritzels
	rg = r_rad/sin(delta_rad);								// Radius der Großkugel
	c = scale_of / 6;											// Kopfgame
	df_ritzel = 4*pi*rg*delta_ritzel/360 - 2 * (scale_of + c);	// Fußkegeldurchmesser auf der Großkugel 
	rf_ritzel = df_ritzel / 2;								// Fußbevel_gearius auf der Großkugel
	delta_f_ritzel = rf_ritzel/(2*pi*rg) * 360;				// Kopfkegelwinkel
	rkf_ritzel = rg*sin(delta_f_ritzel);					// Radius des Kegelfußes
	hoehe_f_ritzel = rg*cos(delta_f_ritzel);				// Höhe des Kegels vom Fußkegel
	
	echo("Kegelwinkel Rad = ", delta_rad);
	echo("Kegelwinkel Ritzel = ", delta_ritzel);
 
	df_rad = 4*pi*rg*delta_rad/360 - 2 * (scale_of + c);		// Fußkegeldurchmesser auf der Großkugel 
	rf_rad = df_rad / 2;									// Fußbevel_gearius auf der Großkugel
	delta_f_rad = rf_rad/(2*pi*rg) * 360;					// Kopfkegelwinkel
	rkf_rad = rg*sin(delta_f_rad);							// Radius des Kegelfußes
	hoehe_f_rad = rg*cos(delta_f_rad);						// Höhe des Kegels vom Fußkegel

	echo("Höhe Rad = ", hoehe_f_rad);
	echo("Höhe Ritzel = ", hoehe_f_ritzel);
	
	drehen = istgerade(number_of_teeth_ritzel);
	
	// Rad
	rotate([0,0,180*(1-game)/number_of_teeth_rad*drehen])
		pfeilbevel_gear(scale_of, number_of_teeth_rad, delta_rad, zahnbreite, bohrung_rad, engagement_angle, angle_of_inclination);
	
	// Ritzel
	if (zusammen_gebaut == 1)
		translate([-hoehe_f_ritzel*cos(90-achsenwinkel),0,hoehe_f_rad-hoehe_f_ritzel*sin(90-achsenwinkel)])
			rotate([0,achsenwinkel,0])
				pfeilbevel_gear(scale_of, number_of_teeth_ritzel, delta_ritzel, zahnbreite, bohrung_ritzel, engagement_angle, -angle_of_inclination);
	else
		translate([rkf_ritzel*2+scale_of+rkf_rad,0,0])
			pfeilbevel_gear(scale_of, number_of_teeth_ritzel, delta_ritzel, zahnbreite, bohrung_ritzel, engagement_angle, -angle_of_inclination);

}

// spur_gear (scale_of=1, number_of_teeth=30, hoehe=5, bohrung=0, engagement_angle=20, angle_of_inclination=20);

// herringbone_gear (scale_of=1, number_of_teeth=30, hoehe=5, bohrung=4, engagement_angle=20, angle_of_inclination=30);

// hollow_gear (scale_of=1, number_of_teeth=30, hoehe=5, randbreite=5, engagement_angle=20, angle_of_inclination=20);

// pfeilhollow_gear (scale_of=1, number_of_teeth=30, hoehe=5, randbreite=5, engagement_angle=20, angle_of_inclination=30);

// planetary_gear_units(scale_of=1, number_of_teeth_sonne=15, number_of_teeth_planet=12, hoehe=6, randbreite=5, bohrung=4, engagement_angle=20, angle_of_inclination=30);

// bevel_gear(scale_of=1, number_of_teeth=30,  teilkegelwinkel=45, zahnbreite=5, bohrung=4, engagement_angle=20, angle_of_inclination=20);

// pfeilbevel_gear(scale_of=1, number_of_teeth=30, teilkegelwinkel=45, zahnbreite=5, bohrung=4, engagement_angle=20, angle_of_inclination=30);

// bevel_gearpaar(scale_of=1, number_of_teeth_rad=30, number_of_teeth_ritzel=11, achsenwinkel=100, zahnbreite=5, bohrung=4, engagement_angle = 20, angle_of_inclination=20, zusammen_gebaut=1);

// pfeilbevel_gearpaar(scale_of=1, number_of_teeth_rad=30, number_of_teeth_ritzel=11, achsenwinkel=100, zahnbreite=5, bohrung=4, engagement_angle = 20, angle_of_inclination=30, zusammen_gebaut=1);



